converter

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ToBool

func ToBool(s string) (bool, error)

ToBool converts a string representation to a boolean value.

func ToInt

func ToInt(s string) (int, error)

ToInt converts a string representation to an integer value.

func ToString

func ToString(s string) (string, error)

ToString simply returns the string value as is, satisfying the converter pattern.

Types

This section is empty.

Jump to